@@ -6,13 +6,14 @@ from bs4 import BeautifulSoup
 from beautifultable import BeautifulTable
 from click import echo, style
 from datetime import datetime
+from termcolor import colored
 
 from evalai.utils.auth import get_request_header, get_host_url
 from evalai.utils.common import (
     clean_data,
-    validate_token,
     convert_UTC_date_to_local,
     validate_date_format,
+    validate_token,
 )
 from evalai.utils.config import EVALAI_ERROR_CODES
 from evalai.utils.urls import URLS
@@ -42,8 +43,15 @@ def pretty_print_challenge_data(challenges):
         start_date = convert_UTC_date_to_local(challenge["start_date"])
         end_date = convert_UTC_date_to_local(challenge["end_date"])
         values.extend([creator, start_date, end_date])
-        table.append_row(values)
-    echo(table)
+        table.append_row([colored(values[0], 'white'),
+                          colored(values[1], 'yellow'),
+                          colored(values[2], 'cyan'),
+                          colored(values[3], 'white'),
+                          colored(values[4], 'green'),
+                          colored(values[5], 'red'),
+                          ])
+
+    echo(table, color='yes')
 
 
 def display_challenges(url):
@@ -76,7 +84,7 @@ def display_challenges(url):
     if len(challenges) != 0:
         pretty_print_challenge_data(challenges)
     else:
-        echo("Sorry, no challenges found.")
+        echo(style("Sorry, no challenges found.", bold=True, fg="red"))
 
 
 def display_all_challenge_list():
@@ -138,7 +146,7 @@ def display_ongoing_challenge_list():
     if len(challenges) != 0:
         pretty_print_challenge_data(challenges)
     else:
-        echo("Sorry, no challenges found.")
+        echo(style("Sorry, no challenges found.", bold=True, fg="red"))
 
 
 def display_future_challenge_list():
@@ -233,7 +241,7 @@ def display_participated_or_hosted_challenges(
         if len(challenges) != 0:
             pretty_print_challenge_data(challenges)
         else:
-            echo("Sorry, no challenges found.")
+            echo(style("Sorry, no challenges found.", bold=True, fg="red"))
 
     if is_participant:
         team_url = "{}{}".format(get_host_url(), URLS.participant_teams.value)
@@ -264,9 +272,9 @@ def display_participated_or_hosted_challenges(
                 echo(style("\nParticipated Challenges\n", bold=True))
                 pretty_print_challenge_data(challenges)
             else:
-                echo("Sorry, no challenges found.")
+                echo(style("Sorry, no challenges found.", bold=True, fg="red"))
         else:
-            echo("Sorry, no challenges found.")
+            echo(style("Sorry, no challenges found.", bold=True, fg="red"))
 
 
 def pretty_print_challenge_details(challenge):
@@ -592,7 +600,7 @@ def display_challenge_phase_split_list(challenge_id):
     if len(phase_splits) != 0:
         pretty_print_challenge_phase_split_data(phase_splits)
     else:
-        echo("Sorry, no Challenge Phase Splits found.")
+        echo(style("Sorry, no Challenge Phase Splits found.", bold=True, fg="red"))
 
 
 def pretty_print_leaderboard_data(attributes, results):
@@ -658,4 +666,4 @@ def display_leaderboard(challenge_id, phase_split_id):
         attributes = results[0]["leaderboard__schema"]["labels"]
         pretty_print_leaderboard_data(attributes, results)
     else:
-        echo("Sorry, no Leaderboard results found.")
+        echo(style("Sorry, no Leaderboard results found.", bold=True, fg="red"))
