@@ -4,7 +4,7 @@ import os
 from os.path import expanduser
 
 
-LEN_OF_TOKEN = 40
+LEN_OF_TOKEN = 210
 
 AUTH_TOKEN_FILE_NAME = "token.json"
 
@@ -14,14 +14,20 @@ AUTH_TOKEN_DIR = expanduser("~/.evalai/")
 
 AUTH_TOKEN_PATH = os.path.join(AUTH_TOKEN_DIR, AUTH_TOKEN_FILE_NAME)
 
-API_HOST_URL = os.environ.get("EVALAI_API_URL", "https://evalapi.cloudcv.org")
+API_HOST_URL = os.environ.get("EVALAI_API_URL", "https://eval.ai")
 
-EVALAI_ERROR_CODES = [400, 401, 406]
+EVALAI_ERROR_CODES = [400, 401, 403, 406]
 
 HOST_URL_FILE_PATH = os.path.join(AUTH_TOKEN_DIR, HOST_URL_FILE_NAME)
 
 EVALAI_HOST_URLS = [
-    "https://evalai.cloudcv.org",
-    "https://evalai-staging.cloudcv.org",
+    "https://eval.ai",
+    "https://staging.eval.ai",
     "http://localhost:8888",
 ]
+
+ENVIRONMENT = os.environ.get("EVALAI_CLI_ENVIRONMENT", "PRODUCTION")
+
+LOCAL_DOCKER_REGISTRY_URI = os.environ.get(
+    "EVALAI_LOCAL_DOCKER_REGISTRY_URI", "localhost:5000"
+)
